@@ -41,12 +41,16 @@ from asposeslidescloud.models.arrow_head_properties import ArrowHeadProperties
 from asposeslidescloud.models.axes import Axes
 from asposeslidescloud.models.axis import Axis
 from asposeslidescloud.models.blur_effect import BlurEffect
+from asposeslidescloud.models.chart_category import ChartCategory
 from asposeslidescloud.models.chart_title import ChartTitle
 from asposeslidescloud.models.chart_wall import ChartWall
+from asposeslidescloud.models.common_slide_view_properties import CommonSlideViewProperties
 from asposeslidescloud.models.custom_dash_pattern import CustomDashPattern
+from asposeslidescloud.models.data_point import DataPoint
 from asposeslidescloud.models.disc_usage import DiscUsage
 from asposeslidescloud.models.effect import Effect
 from asposeslidescloud.models.effect_format import EffectFormat
+from asposeslidescloud.models.entity_exists import EntityExists
 from asposeslidescloud.models.error import Error
 from asposeslidescloud.models.error_details import ErrorDetails
 from asposeslidescloud.models.export_format import ExportFormat
@@ -68,9 +72,9 @@ from asposeslidescloud.models.interactive_sequence import InteractiveSequence
 from asposeslidescloud.models.legend import Legend
 from asposeslidescloud.models.line_format import LineFormat
 from asposeslidescloud.models.merging_source import MergingSource
+from asposeslidescloud.models.normal_view_restored_properties import NormalViewRestoredProperties
 from asposeslidescloud.models.notes_slide_export_format import NotesSlideExportFormat
 from asposeslidescloud.models.object_exist import ObjectExist
-from asposeslidescloud.models.one_value_chart_data_point import OneValueChartDataPoint
 from asposeslidescloud.models.ordered_merge_request import OrderedMergeRequest
 from asposeslidescloud.models.outer_shadow_effect import OuterShadowEffect
 from asposeslidescloud.models.output_file import OutputFile
@@ -82,9 +86,7 @@ from asposeslidescloud.models.preset_shadow_effect import PresetShadowEffect
 from asposeslidescloud.models.reflection_effect import ReflectionEffect
 from asposeslidescloud.models.resource_base import ResourceBase
 from asposeslidescloud.models.resource_uri import ResourceUri
-from asposeslidescloud.models.resource_uri_element import ResourceUriElement
 from asposeslidescloud.models.scale_type import ScaleType
-from asposeslidescloud.models.scatter_chart_data_point import ScatterChartDataPoint
 from asposeslidescloud.models.series import Series
 from asposeslidescloud.models.series_marker import SeriesMarker
 from asposeslidescloud.models.shape_export_format import ShapeExportFormat
@@ -107,7 +109,6 @@ from asposeslidescloud.models.add_master_slide import AddMasterSlide
 from asposeslidescloud.models.add_shape import AddShape
 from asposeslidescloud.models.add_slide import AddSlide
 from asposeslidescloud.models.base64_input_file import Base64InputFile
-from asposeslidescloud.models.bubble_chart_data_point import BubbleChartDataPoint
 from asposeslidescloud.models.bubble_series import BubbleSeries
 from asposeslidescloud.models.color_scheme import ColorScheme
 from asposeslidescloud.models.document import Document
@@ -117,6 +118,7 @@ from asposeslidescloud.models.file_version import FileVersion
 from asposeslidescloud.models.font_scheme import FontScheme
 from asposeslidescloud.models.format_scheme import FormatScheme
 from asposeslidescloud.models.gradient_fill import GradientFill
+from asposeslidescloud.models.header_footer import HeaderFooter
 from asposeslidescloud.models.html_export_options import HtmlExportOptions
 from asposeslidescloud.models.image import Image
 from asposeslidescloud.models.image_export_options import ImageExportOptions
@@ -128,6 +130,8 @@ from asposeslidescloud.models.master_slides import MasterSlides
 from asposeslidescloud.models.merge import Merge
 from asposeslidescloud.models.no_fill import NoFill
 from asposeslidescloud.models.notes_slide import NotesSlide
+from asposeslidescloud.models.notes_slide_header_footer import NotesSlideHeaderFooter
+from asposeslidescloud.models.one_value_chart_data_point import OneValueChartDataPoint
 from asposeslidescloud.models.one_value_series import OneValueSeries
 from asposeslidescloud.models.paragraph import Paragraph
 from asposeslidescloud.models.paragraphs import Paragraphs
@@ -141,6 +145,7 @@ from asposeslidescloud.models.placeholders import Placeholders
 from asposeslidescloud.models.portion import Portion
 from asposeslidescloud.models.portions import Portions
 from asposeslidescloud.models.pptx_export_options import PptxExportOptions
+from asposeslidescloud.models.protection_properties import ProtectionProperties
 from asposeslidescloud.models.remove_shape import RemoveShape
 from asposeslidescloud.models.remove_slide import RemoveSlide
 from asposeslidescloud.models.reorder_slide import ReorderSlide
@@ -151,13 +156,17 @@ from asposeslidescloud.models.response_output_file import ResponseOutputFile
 from asposeslidescloud.models.save import Save
 from asposeslidescloud.models.save_shape import SaveShape
 from asposeslidescloud.models.save_slide import SaveSlide
+from asposeslidescloud.models.scatter_chart_data_point import ScatterChartDataPoint
 from asposeslidescloud.models.scatter_series import ScatterSeries
+from asposeslidescloud.models.section import Section
+from asposeslidescloud.models.sections import Sections
 from asposeslidescloud.models.shape_base import ShapeBase
 from asposeslidescloud.models.shapes import Shapes
 from asposeslidescloud.models.slide import Slide
 from asposeslidescloud.models.slide_animation import SlideAnimation
 from asposeslidescloud.models.slide_background import SlideBackground
 from asposeslidescloud.models.slide_comments import SlideComments
+from asposeslidescloud.models.slide_properties import SlideProperties
 from asposeslidescloud.models.slides import Slides
 from asposeslidescloud.models.solid_fill import SolidFill
 from asposeslidescloud.models.split_document_result import SplitDocumentResult
@@ -168,7 +177,10 @@ from asposeslidescloud.models.theme import Theme
 from asposeslidescloud.models.tiff_export_options import TiffExportOptions
 from asposeslidescloud.models.update_background import UpdateBackground
 from asposeslidescloud.models.update_shape import UpdateShape
+from asposeslidescloud.models.view_properties import ViewProperties
 from asposeslidescloud.models.xps_export_options import XpsExportOptions
+from asposeslidescloud.models.box_and_whisker_series import BoxAndWhiskerSeries
+from asposeslidescloud.models.bubble_chart_data_point import BubbleChartDataPoint
 from asposeslidescloud.models.chart import Chart
 from asposeslidescloud.models.document_replace_result import DocumentReplaceResult
 from asposeslidescloud.models.geometry_shape import GeometryShape
@@ -177,12 +189,14 @@ from asposeslidescloud.models.group_shape import GroupShape
 from asposeslidescloud.models.ole_object_frame import OleObjectFrame
 from asposeslidescloud.models.slide_replace_result import SlideReplaceResult
 from asposeslidescloud.models.smart_art import SmartArt
-from asposeslidescloud.models.smart_art_shape import SmartArtShape
 from asposeslidescloud.models.table import Table
+from asposeslidescloud.models.waterfall_chart_data_point import WaterfallChartDataPoint
+from asposeslidescloud.models.waterfall_series import WaterfallSeries
 from asposeslidescloud.models.audio_frame import AudioFrame
 from asposeslidescloud.models.connector import Connector
 from asposeslidescloud.models.picture_frame import PictureFrame
 from asposeslidescloud.models.shape import Shape
+from asposeslidescloud.models.smart_art_shape import SmartArtShape
 from asposeslidescloud.models.video_frame import VideoFrame
 
 
@@ -190,6 +204,9 @@ from asposeslidescloud.models.video_frame import VideoFrame
 from asposeslidescloud.models.requests.slides_api_requests import CopyFileRequest
 from asposeslidescloud.models.requests.slides_api_requests import CopyFolderRequest
 from asposeslidescloud.models.requests.slides_api_requests import CreateFolderRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteChartCategoryRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteChartDataPointRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteChartSeriesRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteFileRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteFolderRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteNotesSlideRequest
@@ -203,6 +220,8 @@ from asposeslidescloud.models.requests.slides_api_requests import DeleteParagrap
 from asposeslidescloud.models.requests.slides_api_requests import DeleteParagraphsRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeletePortionRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeletePortionsRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSectionRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSectionsRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationEffectRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAnimationInteractiveSequenceRequest
@@ -212,10 +231,16 @@ from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideAni
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideByIndexRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapeRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideShapesRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideSubshapeRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSlideSubshapesRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesCleanSlidesListRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesDocumentPropertyRequest
 from asposeslidescloud.models.requests.slides_api_requests import DeleteSlidesSlideBackgroundRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSubshapeParagraphRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSubshapeParagraphsRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSubshapePortionRequest
+from asposeslidescloud.models.requests.slides_api_requests import DeleteSubshapePortionsRequest
 from asposeslidescloud.models.requests.slides_api_requests import DownloadFileRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetDiscUsageRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetFileVersionsRequest
@@ -225,6 +250,8 @@ from asposeslidescloud.models.requests.slides_api_requests import GetLayoutSlide
 from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlideRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetMasterSlidesListRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideExistsRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideHeaderFooterRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideShapeParagraphsRequest
@@ -234,11 +261,17 @@ from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideS
 from asposeslidescloud.models.requests.slides_api_requests import GetNotesSlideWithFormatRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetParagraphPortionsRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSectionsRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlideAnimationRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlideHeaderFooterRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapeParagraphsRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlideShapesRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlideSubshapeRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlideSubshapeParagraphRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlideSubshapeParagraphsRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlideSubshapesRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesDocumentPropertyRequest
@@ -248,30 +281,46 @@ from asposeslidescloud.models.requests.slides_api_requests import GetSlidesImage
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholderRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPlaceholdersRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesPresentationTextItemsRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlidesProtectionPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideBackgroundRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideCommentsRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideImagesRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlidePropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlideTextItemsRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesSlidesListRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeColorSchemeRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFontSchemeRequest
 from asposeslidescloud.models.requests.slides_api_requests import GetSlidesThemeFormatSchemeRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSlidesViewPropertiesRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSubshapeParagraphPortionRequest
+from asposeslidescloud.models.requests.slides_api_requests import GetSubshapeParagraphPortionsRequest
 from asposeslidescloud.models.requests.slides_api_requests import MoveFileRequest
 from asposeslidescloud.models.requests.slides_api_requests import MoveFolderRequest
 from asposeslidescloud.models.requests.slides_api_requests import ObjectExistsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostAddNewParagraphRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostAddNewPortionRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostAddNewShapeRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostAddNewSubshapeRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostAddNewSubshapeParagraphRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostAddNewSubshapePortionRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostAddNotesSlideRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostChartCategoryRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostChartDataPointRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostChartSeriesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostCopyLayoutSlideFromSourcePresentationRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostCopyMasterSlideFromSourcePresentationRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostGetNotesSlideRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostGetNotesSlideExistsRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostGetNotesSlideWithFormatRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewParagraphRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewPortionRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideAddNewShapeRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostNotesSlideShapeSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostPresentationMergeRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostSectionRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostSectionMoveRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostShapeSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationEffectRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlideAnimationInteractiveSequenceRequest
@@ -282,6 +331,7 @@ from asposeslidescloud.models.requests.slides_api_requests import PostSlidesConv
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesCopyRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromHtmlRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromPdfRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromSourceRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesDocumentFromTemplateRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesPipelineRequest
@@ -292,25 +342,41 @@ from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSave
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSetDocumentPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSlideReplaceTextRequest
 from asposeslidescloud.models.requests.slides_api_requests import PostSlidesSplitRequest
+from asposeslidescloud.models.requests.slides_api_requests import PostSubshapeSaveAsRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutChartCategoryRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutChartDataPointRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutChartSeriesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutLayoutSlideRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutNotesSlideHeaderFooterRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutNotesSlideShapeSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutPresentationMergeRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSectionRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSectionsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPortionPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSetParagraphPropertiesRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSetSubshapeParagraphPortionPropertiesRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSetSubshapeParagraphPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutShapeSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationEffectRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlideAnimationInteractiveSequenceEffectRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlideHeaderFooterRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlideSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlideShapeInfoRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlideSubshapeInfoRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesConvertRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesDocumentFromHtmlRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlidesHeaderFooterRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlidesProtectionPropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSetDocumentPropertyRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideBackgroundColorRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlidePropertiesRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutSlidesSlideSizeRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSlidesViewPropertiesRequest
+from asposeslidescloud.models.requests.slides_api_requests import PutSubshapeSaveAsRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeRequest
 from asposeslidescloud.models.requests.slides_api_requests import PutUpdateNotesSlideShapeParagraphRequest
