@@ -42,24 +42,51 @@ class ExportOptions(object):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'default_regular_font': 'str',
         'format': 'str'
     }
 
     attribute_map = {
+        'default_regular_font': 'defaultRegularFont',
         'format': 'format'
     }
 
     type_determiners = {
     }
 
-    def __init__(self, format=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, format=None):  # noqa: E501
         """ExportOptions - a model defined in Swagger"""  # noqa: E501
 
+        self._default_regular_font = None
         self._format = None
 
+        if default_regular_font is not None:
+            self.default_regular_font = default_regular_font
         if format is not None:
             self.format = format
 
+    @property
+    def default_regular_font(self):
+        """Gets the default_regular_font of this ExportOptions.  # noqa: E501
+
+        Setting user password to protect the PDF document.   # noqa: E501
+
+        :return: The default_regular_font of this ExportOptions.  # noqa: E501
+        :rtype: str
+        """
+        return self._default_regular_font
+
+    @default_regular_font.setter
+    def default_regular_font(self, default_regular_font):
+        """Sets the default_regular_font of this ExportOptions.
+
+        Setting user password to protect the PDF document.   # noqa: E501
+
+        :param default_regular_font: The default_regular_font of this ExportOptions.  # noqa: E501
+        :type: str
+        """
+        self._default_regular_font = default_regular_font
+
     @property
     def format(self):
         """Gets the format of this ExportOptions.  # noqa: E501
