@@ -54,12 +54,11 @@ class GraphicalObject(ShapeBase):
         'x': 'float',
         'y': 'float',
         'z_order_position': 'int',
-        'shapes': 'ResourceUriElement',
+        'shapes': 'ResourceUri',
         'fill_format': 'FillFormat',
         'effect_format': 'EffectFormat',
         'line_format': 'LineFormat',
-        'type': 'str',
-        'shape_type': 'str'
+        'type': 'str'
     }
 
     attribute_map = {
@@ -78,20 +77,17 @@ class GraphicalObject(ShapeBase):
         'fill_format': 'fillFormat',
         'effect_format': 'effectFormat',
         'line_format': 'lineFormat',
-        'type': 'type',
-        'shape_type': 'shapeType'
+        'type': 'type'
     }
 
     type_determiners = {
         'type': 'GraphicalObject',
-        'shape_type': 'GraphicalObject',
     }
 
-    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='GraphicalObject', shape_type='GraphicalObject'):  # noqa: E501
+    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='GraphicalObject'):  # noqa: E501
         """GraphicalObject - a model defined in Swagger"""  # noqa: E501
-        super(GraphicalObject, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)
+        super(GraphicalObject, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type)
         self.type: 'GraphicalObject'
-        self.shape_type: 'GraphicalObject'
 
     def to_dict(self):
         """Returns the model properties as a dict"""
