@@ -30,9 +30,9 @@ import re  # noqa: F401
 
 import six
 
-from asposeslidescloud.models.shape_base import ShapeBase
+from asposeslidescloud.models.geometry_shape import GeometryShape
 
-class SmartArtShape(ShapeBase):
+class SmartArtShape(GeometryShape):
 
 
     """
@@ -54,7 +54,7 @@ class SmartArtShape(ShapeBase):
         'x': 'float',
         'y': 'float',
         'z_order_position': 'int',
-        'shapes': 'ResourceUriElement',
+        'shapes': 'ResourceUri',
         'fill_format': 'FillFormat',
         'effect_format': 'EffectFormat',
         'line_format': 'LineFormat',
@@ -84,14 +84,12 @@ class SmartArtShape(ShapeBase):
 
     type_determiners = {
         'type': 'SmartArtShape',
-        'shape_type': 'Custom',
     }
 
-    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='SmartArtShape', shape_type='Custom'):  # noqa: E501
+    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='SmartArtShape', shape_type=None):  # noqa: E501
         """SmartArtShape - a model defined in Swagger"""  # noqa: E501
         super(SmartArtShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)
         self.type: 'SmartArtShape'
-        self.shape_type: 'Custom'
 
     def to_dict(self):
         """Returns the model properties as a dict"""
