@@ -43,6 +43,7 @@ class SwfExportOptions(ExportOptions):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'default_regular_font': 'str',
         'format': 'str',
         'show_hidden_slides': 'bool',
         'compressed': 'bool',
@@ -67,6 +68,7 @@ class SwfExportOptions(ExportOptions):
     }
 
     attribute_map = {
+        'default_regular_font': 'defaultRegularFont',
         'format': 'format',
         'show_hidden_slides': 'showHiddenSlides',
         'compressed': 'compressed',
@@ -94,9 +96,9 @@ class SwfExportOptions(ExportOptions):
         'format': 'swf',
     }
 
-    def __init__(self, format='swf', show_hidden_slides=None, compressed=None, viewer_included=None, show_page_border=None, show_full_screen=None, show_page_stepper=None, show_search=None, show_top_pane=None, show_bottom_pane=None, show_left_pane=None, start_open_left_pane=None, enable_context_menu=None, logo_image=None, logo_link=None, jpeg_quality=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, format='swf', show_hidden_slides=None, compressed=None, viewer_included=None, show_page_border=None, show_full_screen=None, show_page_stepper=None, show_search=None, show_top_pane=None, show_bottom_pane=None, show_left_pane=None, start_open_left_pane=None, enable_context_menu=None, logo_image=None, logo_link=None, jpeg_quality=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
         """SwfExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(SwfExportOptions, self).__init__(format)
+        super(SwfExportOptions, self).__init__(default_regular_font, format)
 
         self._show_hidden_slides = None
         self._compressed = None
